@@ -1,9 +1,9 @@
 /**
  * @file discinfo.c
- * @brief ǥϢ
+ * @brief fBXN擾֘A
  * @author BananaJinn
- * @version $Id: discinfo.c,v 1.6 2006/07/03 15:53:41 bananajinn Exp $
- * ʣ̲
+ * @version $Id: discinfo.c,v 1.8 2007/01/30 15:49:27 bananajinn Exp $
+ * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #include <stdio.h>
@@ -13,6 +13,7 @@
 # include <io.h>
 #endif
 
+#include "mem.h"
 #include "aspi.h"
 #include "struct.h"
 #include "cmd.h"
@@ -24,18 +25,18 @@
 
 
 /**
- * ǥ(᡼ե˵Ͽ)
- * @param[in]	drive	ֹ¤
- * @param[in]	discinfo  ǥ
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * fBXNݒ(C[Wt@CɋL^)
+ * @param[in]	drive	u\
+ * @param[in]	discinfo  fBXN
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 int SetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
   int ret;
 
   if(drive->type == CMDDRVTYPE_ISO){
-    /* ISO᡼ξϡ1ȥå/1åΤ */
+    /* ISOC[W̏ꍇ́A1gbN/1ZbV̂ */
     if(discinfo->tracks > 1){
       UIDispMessage(MSG_CANT_CREATE_MULTITRACK_ISO,
 		    UIDMT_ERROR);
@@ -43,8 +44,8 @@ int SetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
     }
   }
   else if(drive->type == CMDDRVTYPE_IMAGE){
-    /* ʣ̲ꥸʥ륤᡼ */
-    /* ᡼ե˥ǥ񤭹 */
+    /* ~ՕʉIWiC[W */
+    /* C[Wt@CɃfBXN */
     ret = EmgWriteDiscInformation(&drive->u.image, discinfo);
     if(ret!=RET_OK)
       return ret;
@@ -55,14 +56,14 @@ int SetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
 
 
 /**
- * TAOϿ줿ΤɤȽ̤
- * @param[in]	drive	ɥ饤ֹ¤
- * @param[in]	discinfo  ǥ¤
- * @param[in]	sess_num  åֹ
- * @param[out]	result    Ƚ̷(TAO=TRUE)
- * @param[out]	lout_start  Lead-outϥɥ쥹
- * @retval	RET_OK  ｪλ
- * @retval	RET_NG	顼
+ * TAOL^ꂽ̂ǂ𔻕ʂ
+ * @param[in]	drive	hCu\
+ * @param[in]	discinfo  fBXN\
+ * @param[in]	sess_num  ZbVԍ
+ * @param[out]	result    ʌ(TAO=TRUE)
+ * @param[out]	lout_start  Lead-outJnAhX
+ * @retval	RET_OK  I
+ * @retval	RET_NG	G[
  */
 static int JudgeTAO(CMDDRIVE *drive, CPDISCINFO *discinfo,
 		    WORD sess_num, BOOL *result, DWORD *lout_start)
@@ -81,27 +82,27 @@ static int JudgeTAO(CMDDRIVE *drive, CPDISCINFO *discinfo,
   *lout_start = 0UL;
   *result = FALSE;
   if(!DT_CD_FAMILY(drive->disc_type)){
-    *result = TRUE;	/* DVDϤξTAOȤ */
+    *result = TRUE;	/* DVDn̏ꍇTAOƂ */
     DebugLog("JudgeTAO: TAO(Disc is not CD.)\n");
     return RET_OK;
   }
 
   if(sess_num == discinfo->sessions){
-    /* ǽåξϥץ󥻥å󤫤ɤǧ */
+    /* ŏIZbV̏ꍇ̓I[vZbVǂmF */
     if(discinfo->last_sess_stat == SESSSTAT_EMPTY){
       *result = FALSE;
       DebugLog("JudgeTAO: Session is empty.\n");
       return RET_OK;
     }
     else if(discinfo->last_sess_stat == SESSSTAT_INCOMPLETE){
-      /* ̤λåξTAOȤ */
+      /* ZbV̏ꍇTAOƂ */
       *result = TRUE;
       DebugLog("JudgeTAO: TAO(Last session is incomplete.)\n");
       return RET_OK;
     }
   }
 
-  /* TOC󤫤鳺åΥ꡼ɥȳϥɥ쥹 */
+  /* TOC񂩂YZbṼ[hAEgJnAhX߂ */
   ret = SendReadToc(drive, sess_num, 1, RTF_FULLTOC);
   if(ret==RET_OK){
     for(i=sizeof(struct _TOCHEADER); i<drive->bufsize; i+=sizeof(struct _FULLTOCDESC)){
@@ -123,36 +124,36 @@ static int JudgeTAO(CMDDRIVE *drive, CPDISCINFO *discinfo,
       }
     }
     /*
-     * Run-outȲꤷƤ +2 롣
-     * ºݤɤǥɥ쥹顼ʤ Run-out ̵äȤˤ롣
+     * Run-outƉ肵Ă +2 B
+     * ۂɓǂŃAhXG[Ȃ Run-out ͖ƂɂB
      */
     lba += 2;
   }
   
   if(lba==0UL){
-    /* 餯ץ󥻥åʤΤǡTAO */
+    /* 炭I[vZbVȂ̂ŁATAO */
     *result = TRUE;
     DebugLog("JudgeTAO: TAO(Lead-out start is 0!?)\n");
     return RET_OK;
   }
   
-  /* ꡼ɥȳϥɥ쥹ľ2֥åɤǤߤ */
+  /* [hAEgJnAhX̒O2ubNǂł݂ */
   ret = SendReadCD(drive, lba-2, 2);
   if(ret != RET_OK){
     if(SD_ASC(drive)==0x21){
-      /* Run-out ̵äΤǡSAOȤ */
+      /* Run-out ͖̂ŁASAOƂ */
       *result = FALSE;
       lba -= 2;
       DebugLog("JudgeTAO: SAO(Run-out is not found.)\n");
     }
     else{
-      /* Run-out ȤǡTAOȤ */
+      /* Run-out 낤ƂŁATAOƂ */
       *result = TRUE;
       DebugLog("JudgeTAO: TAO(Run-out is found.)\n");
     }
   }
   else{
-    /* ɤ᤿顢餯 Run-out ϿƤʤΤ SAO */
+    /* ǂ߂A炭 Run-out L^ĂȂ̂ SAO */
     DebugLog("JudgeTAO: SAO(Run-out is not found.)\n");
     *result = FALSE;
   }
@@ -163,11 +164,11 @@ static int JudgeTAO(CMDDRIVE *drive, CPDISCINFO *discinfo,
 }
 
 /**
- * ɼ֤λȥåΥץꥮåĹ
- * @param[in]	drive	ɼֹ¤
- * @param[in/out] cpti	ȥå
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * ǎ摕u̎wgbÑvMbv擾
+ * @param[in]	drive	ǎ摕u\
+ * @param[in/out] cpti	gbN
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 {
@@ -178,12 +179,12 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 
   track_start = Get4bytes(cpti->trackinfo.track_start);
   search_end = track_start;
-  search_start = search_end - 151;	/* GAPĹ=150ŪʤΤǡμ鸡 */
+  search_start = search_end - 151;	/* GAP=150ʓIȂ̂ŁA̎O猟 */
   real_start = search_start;
 
   while(TRUE){
     /*
-     * ʬõ⥷󥷥ǥ֤®
+     * QTV[PVŃANZXԂ񑬂
      */
     for(lba=search_start; lba<search_end; lba++){
       ret = GetSubQ(drive, lba, 1);
@@ -192,7 +193,7 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 	continue;
       }
       if((drive->data_buf[0] & 0x0f)!=0x01){
-	/* ֤ISRCMediaCatalogNumberϿƤ */
+	/* ԂISRCMediaCatalogNumberL^Ă */
 	search_start++;
 	continue;
       }
@@ -201,7 +202,7 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
       }
     }
     if(lba==real_start){
-      /* Ƭ˥åפʤ顢ä鸡 */
+      /* 擪ɃMbvȂAƑO猟 */
       search_end = search_start;
       search_start -= 150;
       real_start = search_start;
@@ -217,7 +218,7 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
     cpti->pause_len = (WORD)(track_start - lba);
 
   if(cpti->pause_len>0){
-    /* ǰΤᡢåפκǸǧ */
+    /* Ô߁AMbv̍ŌmF */
     ret = GetSubQ(drive, Get4bytes(cpti->trackinfo.track_start)-1, 1);
     if(ret==RET_OK){
       if((drive->data_buf[0] & 0x0f)==0x01 &&
@@ -232,12 +233,12 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 }
 
 /**
- * ȥå
- * @param[in]	drive	ɼֹ¤
- * @param[in]	track_num	ȥåֹ
- * @param[out]	cpti	ȥå
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * gbN擾
+ * @param[in]	drive	ǎ摕u\
+ * @param[in]	track_num	gbNԍ
+ * @param[out]	cpti	gbN
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 static int GetTrackInformation(CMDDRIVE *drive, WORD track_num, CPTRACKINFO *cpti)
 {
@@ -256,7 +257,7 @@ static int GetTrackInformation(CMDDRIVE *drive, WORD track_num, CPTRACKINFO *cpt
   if(DT_CD_FAMILY(drive->disc_type)){
     memset(cpti->isrc, 0, 12+1);
     if(IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-      /* MODE2ɤĴ٤ */
+      /* MODE2ǂ𒲂ׂ */
       ret = SendReadCD(drive, Get4bytes(cpti->trackinfo.track_start), 1);
       if(ret!=RET_OK){
 	DispCommandError(drive);
@@ -275,7 +276,7 @@ static int GetTrackInformation(CMDDRIVE *drive, WORD track_num, CPTRACKINFO *cpt
 	memcpy(cpti->isrc, drive->data_buf+9, 12);
       }
       if(track_num>1){
-	/* åĹĴ٤ */
+	/* Mbv𒲂ׂ */
 	ret = GetGapLen(drive, cpti);
 	if(ret!=RET_OK){
 	  return ret;
@@ -294,13 +295,13 @@ static int GetTrackInformation(CMDDRIVE *drive, WORD track_num, CPTRACKINFO *cpt
 }
 
 /**
- * ȥåĴ
- * @param[in]	drive	ɼֹ¤
- * @param[in/out] discinfo ǥ
- * @param[in]	track_num  ȥåֹ
- * @param[in]	lout_start Lead-outϥɥ쥹
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * gbNTCY𒲐
+ * @param[in]	drive	ǎ摕u\
+ * @param[in/out] discinfo fBXN
+ * @param[in]	track_num  gbNԍ
+ * @param[in]	lout_start Lead-outJnAhX
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
 			   WORD track_num, DWORD lout_start)
@@ -322,13 +323,13 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
   next_start = lout_start;
   cpti = &discinfo->trackinfo[track_num-1];
   if(cpti->tao){
-    /* λȥåʤȥåκǸ2֥åɤǤߤ */
+    /* gbNȂgbN̍Ō2ubNǂł݂ */
     if(Get4bytes(cpti->trackinfo.free_blocks)==0){
       lba = Get4bytes(cpti->trackinfo.track_start) + 
 	Get4bytes(cpti->trackinfo.track_size) -2;
       ret = SendReadCD(drive, lba, 2);
       if(ret!=RET_OK){
-	/* ɤʤʤ餿֤ Run-out Ǥ礦 */
+	/* ǂ߂ȂȂ炽Ԃ Run-out ł傤 */
 	track_size = Get4bytes(cpti->trackinfo.track_size) -2;
 	Set4bytes(cpti->trackinfo.track_size, track_size);
       }
@@ -339,7 +340,7 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
     ncpti = &discinfo->trackinfo[track_num];
     if(((WORD)cpti->trackinfo.session_number_msb<<8 | cpti->trackinfo.session_number_lsb)==
        ((WORD)ncpti->trackinfo.session_number_msb<<8 | ncpti->trackinfo.session_number_lsb)){
-      /* ΥȥåƱå */
+      /* ̃gbNZbV */
       next_start = Get4bytes(ncpti->trackinfo.track_start);
       if(IS_TRACKMODE_DATA(ncpti->trackinfo.track_mode)){
 	next_start -= 150;
@@ -357,7 +358,7 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
   if(next_start==0)
     return RET_OK;
 
-  /* ºݤɤǤߤ? */
+  /* ۂɓǂł݂? */
   for(lba=next_start-4; lba<next_start; lba++){
     ret = SendReadCD(drive, lba, 1);
     if(ret!=RET_OK)
@@ -367,7 +368,7 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
   track_size = lba-Get4bytes(cpti->trackinfo.track_start);
 #if 0
   if(track_size != Get4bytes(cpti->trackinfo.track_size)){
-    sprintf(buf, "ȥå%d Υ 0x%08lX  0x%08lX ѹޤ",
+    sprintf(buf, "gbN%d ̃TCY 0x%08lX  0x%08lX ɕύX܂B",
 	    track_num, Get4bytes(cpti->trackinfo.track_size), track_size);
     UIDispMessage(buf, UIDMT_INFORMATION);
   }
@@ -378,11 +379,11 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
 }
 
 /**
- * CD-TEXT
- * @param[in]	drive	ɼֹ¤
- * @param[out]	discinfo  ǥ
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * CD-TEXT擾
+ * @param[in]	drive	ǎ摕u\
+ * @param[out]	discinfo  fBXN
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 static int GetCDText(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -395,11 +396,11 @@ static int GetCDText(CMDDRIVE *drive, CPDISCINFO *discinfo)
   }
   len = Get2bytes(drive->data_buf);
   if(len<=2){	/* header(4bytes) - length field(2bytes) */
-		/* CD-TEXTʤ */
+		/* CD-TEXTȂ */
     return RET_OK;
   }
   len -= 2;
-  discinfo->cdtext = (BYTE *)malloc(len);
+  discinfo->cdtext = (BYTE *)MemNew(len);
   if(discinfo->cdtext==NULL)
     return RET_MEMERR;
   memcpy(discinfo->cdtext, drive->data_buf+4, len);
@@ -409,11 +410,11 @@ static int GetCDText(CMDDRIVE *drive, CPDISCINFO *discinfo)
 
 
 /**
- * ǥ(ISO᡼)
- * @param[in]	drive	ɼֹ¤
- * @param[out]	discinfo  ǥ
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * fBXN擾(ISOC[W)
+ * @param[in]	drive	ǎ摕u\
+ * @param[out]	discinfo  fBXN
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 static int GetDiscInformationISO(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -424,7 +425,7 @@ static int GetDiscInformationISO(CMDDRIVE *drive, CPDISCINFO *discinfo)
   off_t file_size;
 #endif
 
-  /* ե륵 */
+  /* t@CTCY擾 */
 #ifdef WIN32
   file_size = _lseeki64(_fileno(drive->u.image.fp), 0, SEEK_END);
   _lseeki64(_fileno(drive->u.image.fp), 0, SEEK_SET);
@@ -435,15 +436,15 @@ static int GetDiscInformationISO(CMDDRIVE *drive, CPDISCINFO *discinfo)
 #endif
   track_size = (DWORD)((file_size+2047)/2048);
 		
-  /* ǥ */
+  /* fBXNݒ */
   discinfo->disc_stat = DISCSTAT_COMPLETE;
   discinfo->last_sess_stat = SESSSTAT_COMPLETE;
   discinfo->last_addr = (DWORD)(track_size-1);
   discinfo->sessions = 1;
   discinfo->tracks = 1;
-  discinfo->trackinfo = (CPTRACKINFO *)malloc(sizeof(CPTRACKINFO));
+  discinfo->trackinfo = (CPTRACKINFO *)MemNew(sizeof(CPTRACKINFO));
   if(discinfo->trackinfo==NULL){
-    free(discinfo->cdtext);
+    MemFree(discinfo->cdtext);
     discinfo->cdtext = NULL;
     return RET_MEMERR;
   }
@@ -461,11 +462,11 @@ static int GetDiscInformationISO(CMDDRIVE *drive, CPDISCINFO *discinfo)
 }
 
 /**
- * ǥ(᡼ե)
- * @param[in]	drive	ɼֹ¤
- * @param[out]	discinfo  ǥ
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * fBXN擾(C[Wt@C)
+ * @param[in]	drive	ǎ摕u\
+ * @param[out]	discinfo  fBXN
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 static int GetDiscInformationImage(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -479,11 +480,11 @@ static int GetDiscInformationImage(CMDDRIVE *drive, CPDISCINFO *discinfo)
 }
 
 /**
- * ǥ(¥ɥ饤)
- * @param[in]	drive	ɼֹ¤
- * @param[out]	discinfo  ǥ
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * fBXN擾(hCu)
+ * @param[in]	drive	ǎ摕u\
+ * @param[out]	discinfo  fBXN
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -518,7 +519,7 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 
   if(discinfo->disc_stat == DISCSTAT_EMPTY){
 	  UIDispMessage(MSG_SOURCE_IS_BLANK
-					/*"ʣ̸ǥϥ֥󥯤Ǥʣ̤Ǥޤ"*/,
+					/*"ʌfBXN̓uNłBʂł܂B"*/,
 					UIDMT_INFORMATION);
 	  return RET_ABORT;
   }	  
@@ -541,30 +542,30 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
     }
   }
 
-  /* ȥåȤ˾ */
+  /* gbNƂɏ擾 */
   UIMeter1Initialize(MSG_READING);
   if(drive->type==CMDDRVTYPE_NET){
     NAUIMeter1Initialize(&drive->u.net, MSG_READING);
   }
-  discinfo->trackinfo = (CPTRACKINFO *)malloc(sizeof(CPTRACKINFO)*discinfo->tracks);
+  discinfo->trackinfo = (CPTRACKINFO *)MemNew(sizeof(CPTRACKINFO)*discinfo->tracks);
   for(track_num=1; track_num<=discinfo->tracks; track_num++){
     UIMeter1Update((float)track_num*100/discinfo->tracks/2);
     if(drive->type==CMDDRVTYPE_NET){
       NAUIMeter1Update(&drive->u.net, (float)track_num*100/discinfo->tracks/2);
     }
     if(UICheckAbort()){
-      free(discinfo->cdtext);
+      MemFree(discinfo->cdtext);
       discinfo->cdtext = NULL;
-      free(discinfo->trackinfo);
+      MemFree(discinfo->trackinfo);
       discinfo->trackinfo = NULL;
       return RET_ABORT;
     }
     cpti = &discinfo->trackinfo[track_num-1];
     ret = GetTrackInformation(drive, track_num, cpti);
     if(ret!=RET_OK){
-      free(discinfo->cdtext);
+      MemFree(discinfo->cdtext);
       discinfo->cdtext = NULL;
-      free(discinfo->trackinfo);
+      MemFree(discinfo->trackinfo);
       discinfo->trackinfo = NULL;
       return ret;
     }
@@ -577,38 +578,38 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
       NAUIMeter1Update(&drive->u.net, (float)track_num*100/discinfo->tracks/2+50);
     }
     if(UICheckAbort()){
-      free(discinfo->cdtext);
+      MemFree(discinfo->cdtext);
       discinfo->cdtext = NULL;
-      free(discinfo->trackinfo);
+      MemFree(discinfo->trackinfo);
       discinfo->trackinfo = NULL;
       return RET_ABORT;
     }
     cpti = &discinfo->trackinfo[track_num-1];
-    /* åTAOϿɤĴ٤ */
+    /* ZbVTAOL^ǂ𒲂ׂ */
     sess_num = (WORD)cpti->trackinfo.session_number_msb<<8 |
       cpti->trackinfo.session_number_lsb;
     if(sess_num != last_sess_num){
       ret = JudgeTAO(drive, discinfo, sess_num, &tao, &lout_start);
       if(ret!=RET_OK){
-	free(discinfo->cdtext);
+	MemFree(discinfo->cdtext);
 	discinfo->cdtext = NULL;
-	free(discinfo->trackinfo);
+	MemFree(discinfo->trackinfo);
 	discinfo->trackinfo = NULL;
 	return ret;
       }
       last_sess_num = sess_num;
     }
     cpti->tao = tao;
-    /* ȥåĴ */
+    /* gbNTCY */
     ret = AdjustTrackSize(drive, discinfo, track_num, lout_start);
     if(ret!=RET_OK){
-      free(discinfo->cdtext);
+      MemFree(discinfo->cdtext);
       discinfo->cdtext = NULL;
-      free(discinfo->trackinfo);
+      MemFree(discinfo->trackinfo);
       discinfo->trackinfo = NULL;
       return ret;
     }
-    /* ǥǽɥ쥹 */
+    /* fBXNŏIAhXXV */
     if(cpti->trackinfo.nwa_valid){
       if(Get4bytes(cpti->trackinfo.next_writable_addr) > Get4bytes(cpti->trackinfo.track_start))
 	last_addr = Get4bytes(cpti->trackinfo.next_writable_addr);
@@ -621,15 +622,15 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
   discinfo->last_addr = last_addr;
   
   if(DT_DVD_FAMILY(drive->disc_type) && discinfo->tracks>1){
-    /* DVDDAOǤʣȥåϿǤʤ */
+    /* DVDDAOł͕gbNL^łȂ */
     if(GetOption()->dao){
-      /* ȥåʣ¸ߤΤ DAO ϿǤޤ\nTAO ǵϿ³Ԥޤ?" */
+      /* gbN݂̂ DAO L^ł܂B\nTAO ŋL^𑱍s܂?" */
       ret = UIDispMessage(MSG_CANT_DAO,
 			  UIDMT_QUESTION);
       if(ret!=UIDMRET_OK){
-	free(discinfo->cdtext);
+	MemFree(discinfo->cdtext);
 	discinfo->cdtext = NULL;
-	free(discinfo->trackinfo);
+	MemFree(discinfo->trackinfo);
 	discinfo->trackinfo = NULL;
 	return RET_ABORT;
       }
@@ -637,20 +638,20 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
     }
   }
 
-  UIMeter1Initialize(MSG_TOTAL /*""*/);
+  UIMeter1Initialize(MSG_TOTAL /*"S"*/);
   if(drive->type==CMDDRVTYPE_NET){
-    NAUIMeter1Initialize(&drive->u.net, MSG_TOTAL /*""*/);
+    NAUIMeter1Initialize(&drive->u.net, MSG_TOTAL /*"S"*/);
   }
 
   return RET_OK;
 }
 
 /**
- * ǥ
- * @param[in]	drive	ɼֹ¤
- * @param[out]	discinfo  ǥ
- * @retval	RET_OK	ｪλ
- * @retval	RET_NG	顼
+ * fBXN擾
+ * @param[in]	drive	ǎ摕u\
+ * @param[out]	discinfo  fBXN
+ * @retval	RET_OK	I
+ * @retval	RET_NG	G[
  */
 int GetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -659,14 +660,14 @@ int GetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
   memset(discinfo, 0, sizeof(CPDISCINFO));
   if(!REALDRIVE(drive)){
     if(drive->type == CMDDRVTYPE_ISO){
-      /* ISO᡼եξ */
+      /* ISOC[Wt@C̏ꍇ */
       ret = GetDiscInformationISO(drive, discinfo);
       if(ret != RET_OK){
 	return ret;
       }
     }
     else{
-      /* ᡼ե뤫ǥ */
+      /* C[Wt@CfBXN𓾂 */
       ret = GetDiscInformationImage(drive, discinfo);
       if(ret != RET_OK){
 	return ret;
@@ -674,7 +675,7 @@ int GetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
     }
   }
   else{
-    /* ¥ɥ饤֤ */
+    /* hCu擾 */
     ret = GetDiscInformationDrive(drive, discinfo);
     if(ret != RET_OK){
       return ret;
