@@ -2,16 +2,18 @@
  * @file drive.c
  * @brief hCuANZX
  * @author BananaJinn
- * @version $Id: drive.c,v 1.9 2006/07/02 13:22:56 bananajinn Exp $
+ * @version $Id: drive.c,v 1.13 2007/10/02 15:10:52 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 
+#include <stdio.h>
 #if !defined(WIN32)
 # include <stdlib.h>
 # include <string.h>
 #endif
 
+#include "mem.h"
 #include "drive.h"
 #include "cmdlog.h"
 #include "cmd.h"
@@ -41,6 +43,12 @@ int SendCmd(CMDDRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag)
 	return RET_NG;
   }
   CmdLog(drive, cdb, buflen, reqflag, ret);
+#ifdef DEBUGCMD
+  DebugLog("SendCmd: %02X %02X %02X %02X %02X %02X %02X %02X %02X %02X %02X %02X len=0x%08lX io=%d\n",
+	   cdb[0], cdb[1], cdb[2], cdb[3], cdb[4], cdb[5],
+	   cdb[6], cdb[7], cdb[8], cdb[9], cdb[10], cdb[11],
+	   buflen, reqflag);
+#endif
 
   if(ret != RET_OK){
     DebugLog("SendCmd: Command error. cmd=%02Xh %X-%02X-%02X\n",
@@ -91,7 +99,7 @@ int InitializeCmdDrive(CMDDRIVE *drive, int bufsize, int cmdlog_size, int type)
   }
 
   if(bufsize>0){
-	drive->data_buf = (BYTE *)malloc(bufsize);
+	drive->data_buf = (BYTE *)MemNew(bufsize);
 	if(drive->data_buf==NULL){
 	  return RET_NG;
 	}
@@ -114,10 +122,10 @@ int InitializeCmdDrive(CMDDRIVE *drive, int bufsize, int cmdlog_size, int type)
   }
   if(ret != RET_OK){
 	if(drive->own_alloc){
-	  free(drive->data_buf);
+	  MemFree(drive->data_buf);
 	  drive->data_buf=NULL;
 	}
-	free(drive->cmdlog);
+	MemFree(drive->cmdlog);
 	drive->cmdlog=NULL;
 	return ret;
   }
@@ -130,7 +138,7 @@ void FreeCmdDrive(CMDDRIVE *drive)
   CmdLogFree(drive);
   if(drive->data_buf!=NULL){
 	if(drive->own_alloc){
-	  free(drive->data_buf);
+	  MemFree(drive->data_buf);
 	}
 	drive->data_buf=NULL;
   }
@@ -180,7 +188,7 @@ int SetDriveAspiSetting(CMDDRIVE *drive, int *ha, int *tg, DWORD *timeout)
   return SetAspiSetting(&drive->u.drive, ha, tg, timeout);
 }
 
-void SetDriveBuffer(CMDDRIVE *drive, char *data_buf, int bufsize)
+void SetDriveBuffer(CMDDRIVE *drive, BYTE *data_buf, int bufsize)
 {
   drive->data_buf = data_buf;
   drive->bufsize = bufsize;
@@ -410,7 +418,8 @@ int OpenNetDevice(CMDDRIVE *drive, BOOL server,
   }
   else{
     /* NCAg[h */
-    drive->u.net.remote_host = strdup(remote_host);
+	  drive->u.net.remote_host = MemNew(strlen(remote_host)+1);
+	  strncpy(drive->u.net.remote_host, remote_host, strlen(remote_host)+1);
     drive->u.net.u.client.remote_port = (WORD)port_number;
     ret = NAConnect(&drive->u.net);
     if(ret!=RET_OK){
