@@ -1,5 +1,10 @@
-/* ~Օʉ
- * Copyright (C) 2004 Kagetani Hideto
+/*
+ * @file drive.h
+ * @brief hCuANZX
+ * @author BananaJinn
+ * @version $Id: drive.h,v 1.9 2007/10/02 15:10:52 bananajinn Exp $
+ * ~Օʉ
+ * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #ifndef __DRIVE_H__
 #define __DRIVE_H__
@@ -88,7 +93,21 @@ extern int InitializeCmdDrive(CMDDRIVE *drive, int bufsize, int cdblog_size, int
 extern void FreeCmdDrive(CMDDRIVE *drive);
 extern void CheckAtapi(CMDDRIVE *drive);
 extern int SetDriveAspiSetting(CMDDRIVE *drive, int *ha, int *tg, DWORD *timeout);
-extern void SetDriveBuffer(CMDDRIVE *drive, char *data_buf, int bufsize);
+extern void SetDriveBuffer(CMDDRIVE *drive, BYTE *data_buf, int bufsize);
+
+extern int OpenDevice(CMDDRIVE *drive, int hid, int tid,
+		      BOOL reader, BOOL bWaitDisc,
+		      BYTE *data_buf, int bufsize);
+extern void CloseDevice(CMDDRIVE *drive);
+extern int OpenTempImageDevice(CMDDRIVE *drive, BOOL reader,
+			       BYTE *data_buf, int bufsize,
+			       const char *tmpfile);
+extern int OpenISOImageDevice(CMDDRIVE *drive, BOOL reader,
+			      BYTE *data_buf, int bufsize);
+extern int OpenEnbanImageDevice(CMDDRIVE *drive, BOOL reader,
+				BYTE *data_buf, int bufsize);
+extern int OpenNetDevice(CMDDRIVE *drive, BOOL server,
+			 BYTE *data_buf, int bufsize);
 
 #ifdef __cplusplus
 }
