@@ -2,7 +2,7 @@
  * @file option.c
  * @brief ʐݒ
  * @author BananaJinn
- * @version $Id: option.c,v 1.16 2006/03/21 14:06:22 bananajinn Exp $
+ * @version $Id: option.c,v 1.21 2007/10/02 15:10:52 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -13,10 +13,8 @@
 # include <pwd.h>
 # include <unistd.h>
 # include <sys/types.h>
-# if !defined(MACOSX)
-#  include <malloc.h>
-# endif	/* !MACOSX */
 #endif	/* !WIN32 */
+#include "mem.h"
 #include "option.h"
 #include "cmd.h"
 #include "ui.h"
@@ -40,7 +38,7 @@ static int GetReadableSpeed(CMDDRIVE *drive, OPTIONS *option)
     option->num_readable_speed = 0;
     return RET_OK;
   }
-  option->readable_speed = (BYTE *)malloc(sizeof(speeds));
+  option->readable_speed = (BYTE *)MemNew(sizeof(speeds));
   if(option->readable_speed == NULL){
     UIDispMessage(MSG_MEM_ALLOC_ERROR
 		  /*"mۂɎs܂B"*/, UIDMT_ERROR);
@@ -121,7 +119,7 @@ static int GetWritableSpeed(CMDDRIVE *drive, OPTIONS *option)
 				  (drive->cmd_type==CMDDRVCTYPE_ATAPI ? 8:16));
     num_wr_speed_des = Get2bytes(mp2a->num_wr_speed_des);
     if(num_wr_speed_des > 0){
-      option->writable_speed = (BYTE *)malloc(num_wr_speed_des*sizeof(BYTE));
+      option->writable_speed = (BYTE *)MemNew(num_wr_speed_des*sizeof(BYTE));
       if(option->writable_speed == NULL){
 	UIDispMessage(MSG_MEM_ALLOC_ERROR
 		      /*"mۂɎs܂B"*/, UIDMT_ERROR);
@@ -142,7 +140,7 @@ static int GetWritableSpeed(CMDDRIVE *drive, OPTIONS *option)
   }
   if(option->num_writable_speed==0){
     /* T|[gx擾łȂꍇ */
-    option->writable_speed = (BYTE *)malloc(sizeof(speeds));
+    option->writable_speed = (BYTE *)MemNew(sizeof(speeds));
     if(option->writable_speed == NULL){
       UIDispMessage(MSG_MEM_ALLOC_ERROR
 		    /*"mۂɎs܂B"*/, UIDMT_ERROR);
@@ -168,6 +166,49 @@ static int GetWritableSpeed(CMDDRIVE *drive, OPTIONS *option)
   return RET_OK;
 }
 
+/**
+ * 1gbNISOC[WǂmF
+ * @param[in]	drive	u
+ * @retval	TRUE	1gbNISȌꍇ
+ * @retval	FALSE	ł͂Ȃꍇ
+ */
+static BOOL Check1TrackISO(CMDDRIVE *drive)
+{
+  struct _DISCINFO *di;
+  int ret;
+  WORD track_num;
+
+  if(!REALDRIVE(drive)){
+    return drive->type == CMDDRVTYPE_ISO;
+  }
+
+  if(DT_DVD_FAMILY(drive->disc_type)){
+    /* CD̂ݑΉ */
+    return FALSE;
+  }
+
+  ret = SendReadDiscInfo(drive);
+  if(ret != RET_OK){
+    return FALSE;
+  }
+  di = (struct _DISCINFO *)drive->data_buf;
+  track_num = (WORD)di->last_track_ls_msb<<8 | di->last_track_ls_lsb;
+  if(track_num != 1){
+    return FALSE;
+  }
+
+  ret = SendRead10(drive, 0x10, 1, 2048);
+  if(ret != RET_OK){
+    return FALSE;
+  }
+  if(strncmp((char *)(drive->data_buf+1), "CD001", 5) != 0){
+    return FALSE;
+  }
+  
+  return TRUE;
+}
+
+
 #if defined(WIN32)
 
 void GetRegString(const char *key, char *string_ret, DWORD size)
@@ -248,7 +289,7 @@ static char *GetOptionFilename()
 	struct passwd *pwent;
 
 	pwent = getpwuid(getuid());
-	fname = (char *)malloc(strlen(pwent->pw_dir)+1+strlen(OPTFNAME)+1);
+	fname = (char *)MemNew(strlen(pwent->pw_dir)+1+strlen(OPTFNAME)+1);
 	if(fname==NULL)
 		return NULL;
 	sprintf(fname, "%s/%s", pwent->pw_dir, OPTFNAME);
@@ -295,7 +336,7 @@ static void LoadOption()
 		return;
 	fp = fopen(fname, "r");
 	if(fp==NULL){
-		free(fname);
+		MemFree(fname);
 		return;
 	}
 
@@ -321,7 +362,7 @@ static void LoadOption()
 	}
 	fclose(fp);
 
-	free(fname);
+	MemFree(fname);
 }
 
 static void SaveOption()
@@ -334,7 +375,7 @@ static void SaveOption()
 		return;
 	fp = fopen(fname, "w");
 	if(fp==NULL){
-		free(fname);
+		MemFree(fname);
 		return;
 	}
 
@@ -343,7 +384,7 @@ static void SaveOption()
 	fprintf(fp, "writespeed=%d\n", g_Option.write_speed);
 	fclose(fp);
 	
-	free(fname);
+	MemFree(fname);
 }
 #endif /* WIN32 */
 
@@ -394,6 +435,12 @@ int SetOption(CMDDRIVE *reader, CMDDRIVE *writer, int disc_type)
     }
   }
 
+  if(DT_DVD_FAMILY(disc_type)){
+    g_Option.flags |= OPFLG_DVD;
+    g_Option.dao = TRUE;
+    g_Option.flags |= OPFLG_DAO;
+  }
+
   if(reader!=NULL && writer!=NULL){
     if(reader->type==CMDDRVTYPE_DRIVE && writer->type==CMDDRVTYPE_DRIVE){
       if(reader->u.drive.hid != writer->u.drive.hid ||
@@ -405,18 +452,13 @@ int SetOption(CMDDRIVE *reader, CMDDRIVE *writer, int disc_type)
     else{
       g_Option.on_the_fly = TRUE;
       g_Option.flags |= OPFLG_ONTHEFLY;
+      g_Option.flags &= ~OPFLG_DAO;
     }
   }
   else{
     g_Option.on_the_fly = TRUE;
   }
 
-  if(DT_DVD_FAMILY(disc_type)){
-    g_Option.flags |= OPFLG_DVD;
-    g_Option.dao = TRUE;
-    g_Option.flags |= OPFLG_DAO;
-  }
-
   ret = GetReadableSpeed(reader, &g_Option);
   if(ret != RET_OK){
     return ret;
@@ -424,20 +466,24 @@ int SetOption(CMDDRIVE *reader, CMDDRIVE *writer, int disc_type)
 
   ret = GetWritableSpeed(writer, &g_Option);
   if(ret != RET_OK){
-    free(g_Option.readable_speed);
+    MemFree(g_Option.readable_speed);
     g_Option.readable_speed=NULL;
     g_Option.num_readable_speed=0;
     return ret;
   }
 
+  if(Check1TrackISO(reader)){
+    g_Option.flags |= OPFLG_OUTSIDE;
+  }
+
   LoadOption();
   ret = UISetting(&g_Option);
   SaveOption();
-  
-  free(g_Option.readable_speed);
+
+  MemFree(g_Option.readable_speed);
   g_Option.readable_speed=NULL;
   g_Option.num_readable_speed=0;
-  free(g_Option.writable_speed);
+  MemFree(g_Option.writable_speed);
   g_Option.writable_speed=NULL;
   g_Option.num_writable_speed=0;
   return ret;
