@@ -7,6 +7,7 @@
 #include <string.h>
 
 #include "filedlg.h"
+#include "text.h"
 
 static int g_RetCode;
 
@@ -26,7 +27,7 @@ static void on_file_canceled(GtkWidget *widget, gpointer user_data)
 int FileDialog(int bOpen, char *filename, int size, const char *suffix)
 {
   GtkWidget *file_selector;
-  const char *title = bOpen ? "ե򳫤" : "ե¸";
+  const char *title = bOpen ? GT("open file") : GT("save file");
   char *mask=NULL;
 
   g_RetCode = FDR_PENDING;
