@@ -1,4 +1,5 @@
-/* ʣ̲
+/**
+ * ʣ̲
  * Copyright (c) 2004 Kagetani Hideto
  */
 
@@ -35,7 +36,6 @@ static int g_WriterEmg = -1;
 static int g_ReaderNet = -1;
 static int g_WriterNet = -1;
 
-
 static int scan_drive(GtkWidget *optmenu, BOOL writer)
 {
   GtkWidget *menu;
@@ -51,8 +51,8 @@ static int scan_drive(GtkWidget *optmenu, BOOL writer)
   gtk_option_menu_remove_menu(GTK_OPTION_MENU(optmenu));
   menu = gtk_menu_new();
 
-  for(count=0; strlen(drives[count].inqdata)!=0; count++){
-    menuitem = gtk_menu_item_new_with_label(drives[count].inqdata);
+  for(count=0; strlen((char *)drives[count].inqdata)!=0; count++){
+	  menuitem = gtk_menu_item_new_with_label((char *)drives[count].inqdata);
     gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(count));
     gtk_menu_append(GTK_MENU(menu), menuitem);
     gtk_widget_show(menuitem);
@@ -168,7 +168,7 @@ on_btnStartCopy_clicked(GtkWidget *widget, gpointer user_data)
 	  /*  */
   if(sel_writer == g_AllWritableDrives){
     writer_num = 0;
-    for(index=0; strlen(g_WriterList[index].inqdata)!=0; index++){
+    for(index=0; strlen((char *)g_WriterList[index].inqdata)!=0; index++){
       if(g_ReaderList[sel_reader].hid == g_WriterList[index].hid &&
 		 g_ReaderList[sel_reader].tid == g_WriterList[index].tid){
 			/* ɼ̵֤ */
@@ -300,7 +300,6 @@ create_mainwindow(void)
   gtk_object_set_data (GTK_OBJECT (window1), "window1", window1);
   gtk_window_set_title (GTK_WINDOW (window1), GT("EnbanFukusyaYa")
 			/*"ʣ̲"*/);
-
   /* ơ֥ */
   table1 = gtk_table_new (7, 3, FALSE);
   gtk_widget_ref (table1);
@@ -517,17 +516,26 @@ create_mainwindow(void)
 }
 
 
-
 int
 main (int argc, char *argv[])
 {
   GtkWidget *mainwindow;
 
   gtk_set_locale();
+#if defined(__MINGW32__)
+  char *rc[] = { "gtkrc", "theme\\gtkrc", NULL };
+  gtk_rc_set_default_files(rc);
+  bindtextdomain("EnbanFukusyaYa", ".");
   bind_textdomain_codeset("EnbanFukusyaYa", "UTF-8");
   textdomain("EnbanFukusyaYa");
+#else
+  bind_textdomain_codeset("EnbanFukusyaYa", "UTF-8");
+  textdomain("EnbanFukusyaYa");
+#endif
   gtk_init(&argc, &argv);
 
+  gtk_window_set_default_icon_from_file("/usr/share/pixmaps/EnbanFukusyaYa.png", NULL);
+
   OpenAspi();
 
   mainwindow = create_mainwindow();
