@@ -3,12 +3,16 @@
 */
 
 #include <mach/mach.h>
-#include <CoreFoundation/CoreFoundation.h>
+#include <paths.h>
+#include <sys/mount.h>
 #include <IOKit/IOKitLib.h>
+#include <IOKit/IOBSD.h>
 #include <IOKit/scsi-commands/SCSITaskLib.h>
+#include <CoreFoundation/CoreFoundation.h>
 #include "aspi.h"
 #include "cmd.h"
 #include "cmdlog.h"
+#include "ui.h"
 
 #define MAXDEVICE	16
 static mach_port_t				masterPort;
@@ -18,6 +22,7 @@ static int numObject;
 static UInt64 transferCount;
 
 
+
 UInt64 GettransferCount(void)
 {
     return transferCount;
@@ -56,7 +61,6 @@ int OpenAspi(void)
 	 */
 	CFDictionarySetValue(matchingDictionary, CFSTR(kIOPropertyMatchKey),
 						subDictionary);
-
 	/*
 	 * foCX
 	 */
@@ -101,24 +105,12 @@ void CloseAspi(void)
 	masterPort=0;
 }
 
-int InitializeDrive(DRIVE *drive, int bufsize, int cmdlog_size)
+int InitializeDrive(DRIVE *drive)
 {
 	FreeDrive(drive);
 	drive->hid = -1;
 	drive->tid = -1;
 
-	CmdLogInit(drive, cmdlog_size);
-	if(drive->data_buf!=NULL){
-		free(drive->data_buf);
-		drive->data_buf = NULL;
-	}
-	if(bufsize>0){
-		drive->data_buf = (BYTE *)malloc(bufsize);
-		if(drive->data_buf==NULL)
-			return RET_NG;
-		drive->bufsize = bufsize;
-	}
-	
 	drive->interface = NULL;
 	drive->mmcInterface = NULL;
 	drive->plugInInterface = NULL;
@@ -147,33 +139,9 @@ static void ClearAspiSetting(DRIVE *drive)
 
 void FreeDrive(DRIVE *drive)
 {
-	CmdLogFree(drive);
-	
-	if(drive->data_buf!=NULL){
-		free(drive->data_buf);
-		drive->data_buf = NULL;
-	}
 	ClearAspiSetting(drive);
 }
 
-static void CheckAtapi(DRIVE *drive)
-{
-	BYTE cdb[12];
-	int ret;
-	
-	memset(cdb, 0, sizeof(cdb));
-	cdb[0] = CMD_MODE_SENSE10;
-	cdb[2] = 0x2a;
-	cdb[8] = 12;
-	ret = SendCmd(drive, cdb, 12, REQ_DATAIN);
-	if(ret!=RET_OK){
-		drive->atapi = FALSE;
-	}
-	else{
-		drive->atapi = drive->data_buf[8]==0x2a;
-	}
-}
-
 
 int SetAspiSetting(DRIVE *drive, int *haid, int *tgid, DWORD *timeout)
 {
@@ -221,24 +189,26 @@ int SetAspiSetting(DRIVE *drive, int *haid, int *tgid, DWORD *timeout)
 				fflush(stdout);
 			}
 			 */
-
+			
 			kr = (*drive->interface)->ObtainExclusiveAccess(drive->interface);
 			if(kr!=noErr){
 				printf("ERR: ObrainExclusiveAccess returned %d\n", kr);
 				if(kr==kIOReturnBusy){
 					printf("Media is still mounted.\n");
-					fflush(stdout);
+					UIDispMessage("fBXN}EgĂ悤łB}EgĂB",
+								  UIDMT_ERROR);
 					return RET_NG;
 				}
 				if(kr==kIOReturnExclusiveAccess){
 					printf("Another sofrware has exclusive access\n");
+					UIDispMessage("Iꂽu͑̃AvP[VŎgpĂ悤łB",
+								  UIDMT_ERROR);
 				}
 				fflush(stdout);
 				return RET_NG;
 			}
 			drive->tid = *tgid;
 		}
-		CheckAtapi(drive);
 	}
 	if(timeout!=NULL){
 		drive->timeout = *timeout;
@@ -281,16 +251,17 @@ static BYTE GetCDBLen( BYTE cdb0 )
 	return len;
 }
 
-int SendCmd(DRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag)
+int SendAspiCmd(DRIVE *drive, BYTE *cdb, BYTE *buf, DWORD buflen,
+				BYTE *sensedata, DWORD senselen, BYTE reqflag)
 {
 	SCSITaskInterface **task;
 	SCSITaskStatus taskStatus;
+	SCSI_Sense_Data senseData;
 	IOReturn ioRet;
 	BYTE cdblen, transdir;
 	IOVirtualRange	range;
 	int retcode;
 
-	drive->cmdcode = cdb[0];
 	cdblen = GetCDBLen(cdb[0]);
 	switch(reqflag){
 	case REQ_DATAOUT:	transdir = kSCSIDataTransfer_FromInitiatorToTarget;	break;
@@ -298,12 +269,12 @@ int SendCmd(DRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag)
 	default:	transdir = kSCSIDataTransfer_NoDataTransfer;
 	}
 
-	memset(&drive->sense_data, 0, SENSEDATA_SIZE);
+	memset(&senseData, 0, SENSEDATA_SIZE);
 
 	task = (*drive->interface)->CreateSCSITask(drive->interface);
 	if(task==NULL)
 		return RET_NG;
-	range.address = (IOVirtualAddress)drive->data_buf;
+	range.address = (IOVirtualAddress)buf;
 	range.length = buflen;
 	ioRet = (*task)->SetCommandDescriptorBlock(task, cdb, cdblen);
 	if(ioRet != kIOReturnSuccess){
@@ -324,13 +295,15 @@ int SendCmd(DRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag)
 		(*task)->Release(task);
 		return RET_NG;
 	}
-	ioRet = (*task)->ExecuteTaskSync(task, (SCSI_Sense_Data *)drive->sense_data, &taskStatus, &transferCount);
+	ioRet = (*task)->ExecuteTaskSync(task, &senseData, &taskStatus, &transferCount);
 	if(ioRet!=kIOReturnSuccess){
 		printf("ERR: Executing Task\n");
 		(*task)->Release(task);
 		return RET_NG;
 	}
                 
+	memcpy(sensedata, &senseData, 
+		   (sizeof(senseData) < senselen) ? sizeof(senseData) : senselen);
 	if(taskStatus==kSCSITaskStatus_GOOD){
 		(*task)->Release(task);
 		retcode = RET_OK;
@@ -344,7 +317,6 @@ int SendCmd(DRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag)
 		return RET_NG;
 	}
 
-	CmdLog(drive, cdb, buflen, reqflag, retcode);
 	return retcode;
 }
 
@@ -361,12 +333,60 @@ io_service_t *GetSCSIObject(int drive_number)
     return &scsiObjects[drive_number];
 }
 
+static int GetDeviceIF(int targetid,
+						IOCFPlugInInterface ***plugInInterface,
+						MMCDeviceInterface ***mmcInterface)
+{
+  kern_return_t kr;
+  HRESULT herr;
+  SInt32 score;
+
+  *plugInInterface = NULL;
+  *mmcInterface = NULL;
+  
+  kr = IOCreatePlugInInterfaceForService(*GetSCSIObject(targetid),
+										 kIOMMCDeviceUserClientTypeID,
+										 kIOCFPlugInInterfaceID,
+										 plugInInterface,
+										 &score);
+  if(kr != noErr){
+	goto ERRRET;
+  }
+  herr = (**plugInInterface)->QueryInterface(*plugInInterface,
+											 CFUUIDGetUUIDBytes(kIOMMCDeviceInterfaceID),
+											 (LPVOID)mmcInterface);
+  if(herr != S_OK){
+	goto ERRRET;
+  }
+  
+  return RET_OK;
+
+ERRRET:
+	if(*mmcInterface != NULL){
+		(**mmcInterface)->Release(*mmcInterface);
+	}
+	if(*plugInInterface != NULL){
+		IODestroyPlugInInterface(*plugInInterface);
+	}
+	return RET_NG;
+}
+
+
+static void FreeDeviceIF(IOCFPlugInInterface **plugInInterface,
+						 MMCDeviceInterface **mmcInterface)
+{
+	if(mmcInterface != NULL){
+		(*mmcInterface)->Release(mmcInterface);
+	}
+	if(plugInInterface != NULL){
+		IODestroyPlugInInterface(plugInInterface);
+	}
+}
+
+
 int GetInquiryString(int targetid, char *buff, int bufsize)
 {
 	int count;
-	HRESULT		herr;
-	kern_return_t	kr;
-	SInt32	score;
 	IOReturn ioret;
 	IOCFPlugInInterface 	**plugInInterface = NULL;
 	MMCDeviceInterface	**mmcInterface = NULL;
@@ -374,23 +394,13 @@ int GetInquiryString(int targetid, char *buff, int bufsize)
 	SCSITaskStatus taskStatus;
 	SCSI_Sense_Data senseDataBuffer;
 	unsigned char *bufptr = (unsigned char *)&inqbuf;
-	int myerr = RET_NG;
+	int ret;
 	
 	memset(bufptr, '\0', sizeof(SCSICmd_INQUIRY_StandardData));
-	
-	kr = IOCreatePlugInInterfaceForService(*GetSCSIObject(targetid),
-										kIOMMCDeviceUserClientTypeID,
-										kIOCFPlugInInterfaceID,
-										&plugInInterface,
-										&score);
-	if(kr!=noErr){
-		goto ERRRET;
-	}
-	herr = (*plugInInterface)->QueryInterface(plugInInterface,
-										   CFUUIDGetUUIDBytes(kIOMMCDeviceInterfaceID),
-										   (LPVOID)&mmcInterface);
-	if(herr!=S_OK){
-		goto ERRRET;
+
+	ret = GetDeviceIF(targetid, &plugInInterface, &mmcInterface);
+	if(ret != RET_OK){
+	  return RET_NG;
 	}
 	
 	/* Inquirys */
@@ -401,12 +411,13 @@ int GetInquiryString(int targetid, char *buff, int bufsize)
 								  &senseDataBuffer);
 	if(ioret==kIOReturnExclusiveAccess){
 		/* rIANZX擾G[ */
-		myerr = RET_NG;
-		goto ERRRET;
+	  FreeDeviceIF(plugInInterface, mmcInterface);
+	  return RET_NG;
 	}
 	else if(ioret!=kIOReturnSuccess){
 		/* ̑̃G[ */
-		goto ERRRET;
+	  FreeDeviceIF(plugInInterface, mmcInterface);
+	  return RET_NG;
 	}
 	
 	if(bufsize>sizeof(inqbuf)-8+1){
@@ -425,19 +436,66 @@ int GetInquiryString(int targetid, char *buff, int bufsize)
 		buff[bufsize-1]='\0';
 	}
 	
-	(*mmcInterface)->Release(mmcInterface);
-	IODestroyPlugInInterface(plugInInterface);
+	FreeDeviceIF(plugInInterface, mmcInterface);
 	
 	return RET_OK;
-	
-ERRRET:
-	if(mmcInterface!=NULL){
-		(*mmcInterface)->Release(mmcInterface);
-	}
-	if(plugInInterface!=NULL){
-		IODestroyPlugInInterface(plugInInterface);
-	}
-	
-	return myerr;
 }
 
+BOOL MMCIsWriterDrive(int targetid, char *buff, int bufsize)
+{
+  int ret;
+  IOCFPlugInInterface 	**plugInInterface = NULL;
+  MMCDeviceInterface	**mmcInterface = NULL;
+  IOReturn ioret;
+  SCSITaskStatus taskStatus;
+  SCSI_Sense_Data senseDataBuffer;
+  struct _MODEPAGE2A *mp2a;
+  BOOL atapi=TRUE;
+
+  ret = GetDeviceIF(targetid, &plugInInterface, &mmcInterface);
+  if(ret != RET_OK){
+	return FALSE;
+  }
+
+	  /* ATAPI/SCSI */
+  ioret = (*mmcInterface)->ModeSense10(mmcInterface,
+									   0,	/* LLBAA */
+									   0,	/* DBD */
+									   MSPC_CURRENT,	/* PC */
+									   0x2a,	/* PAGE_CODE */
+									   buff,
+									   12,
+									   &taskStatus,
+									   &senseDataBuffer);
+  if(ioret != kIOReturnSuccess){
+	atapi = FALSE;
+  }
+  else{
+	atapi = TRUE;
+  }
+  
+  ioret = (*mmcInterface)->ModeSense10(mmcInterface,
+									   0,	/* LLBAA */
+									   0,	/* DBD */
+									   MSPC_CURRENT,	/* PC */
+									   0x2a,	/* PAGE_CODE */
+									   buff,
+									   bufsize,
+									   &taskStatus,
+									   &senseDataBuffer);
+  if(ioret != kIOReturnSuccess){
+	  FreeDeviceIF(plugInInterface, mmcInterface);
+	  return FALSE;
+  }
+
+  mp2a = (struct _MODEPAGE2A *)(buff + (atapi ? 8:16));
+  if(mp2a->cd_r_write || mp2a->cd_rw_write || mp2a->dvd_r_write){
+	  FreeDeviceIF(plugInInterface, mmcInterface);
+	  return TRUE;
+  }
+  
+  FreeDeviceIF(plugInInterface, mmcInterface);
+  return FALSE;
+}
+
+  
