@@ -644,7 +644,7 @@ void CEnbanFukusyaDlg::OnOK()
 		reader.hid = HID_VIRTUAL;
 		reader.tid = CMDDRVTYPE_ISO;
 	}
-	if(sel_reader == m_nReadDriveEmg){
+	else if(sel_reader == m_nReadDriveEmg){
 		reader.hid = HID_VIRTUAL;
 		reader.tid = CMDDRVTYPE_IMAGE;
 	}
